@@ -154,10 +154,11 @@ def operator_check(left_argument, right_argument, show_failed=False):
                  '.', '%', '==', '!=', '<=', '>=', '~', '^', '<<',
                  '>>', '**', '+=', '-=', '*=', '/=', '%=', '&=', '|=', '^=',
                  '<<=', '>>=', '**=', '//', '//=', '@', '@=', '->', '...',
-                 ':=']
+                 ':=', 'and', 'or', 'in', 'is']
+
     for operator in operators:
         try:
-            x = eval(f'{left_argument} {operator} {right_argument}')
+            x = eval(f'left_argument {operator} right_argument')
             succeeded.add(operator)
         except:
             failed.add(operator)
